// ----------------------------------------------------------------------------
// PhoneBook.java
// creating a phone book and looking it up
// 
// Author:  Wolfgang Schreiner <Wolfgang.Schreiner@fhs-hagenberg.ac.at>
// Created: August 25, 2001
// ----------------------------------------------------------------------------
public class PhoneBook
{
  // --------------------------------------------------------------------------
  // a phone book entry consisting of name and number
  // --------------------------------------------------------------------------
  public static class Entry
  {
    public String name;
    public String number;

    public Entry(String name, String number)
    {
      this.name = name;
      this.number = number;
    }

    public String getName()
    {
      return name;
    }

    public String getNumber()
    {
      return number;
    }
  }

  // --------------------------------------------------------------------------
  // reads a phone book and then uses it
  // --------------------------------------------------------------------------
  public static void main(String[] args)
  {
    Entry[] book = readPhoneBook();
    usePhoneBook(book);
  }

  // --------------------------------------------------------------------------
  // ask the user for a phone book
  // --------------------------------------------------------------------------
  public static Entry[] readPhoneBook()
  {
    System.out.print("How many entries? ");
    int n = Input.readInt();
    Entry[] book = new Entry[n];
    for (int i=0; i<n; i++)
    {
      System.out.println("Entry " + (i+1) + ":");
      book[i] = readEntry();
    }
    return book;
  }

  // --------------------------------------------------------------------------
  // read a phone book entry
  // --------------------------------------------------------------------------
  public static Entry readEntry()
  {
    System.out.print("Enter name: ");
    String name = Input.readString();
    System.out.print("Enter number: ");
    String number = Input.readString();
    return new Entry(name, number);
  }

  // --------------------------------------------------------------------------
  // let the user look up the phone book
  // --------------------------------------------------------------------------
  public static void usePhoneBook(Entry[] book)
  {
    while (true)
    {
      System.out.print("Another lookup (y/n)? ");
      char ch = Input.readChar();
      if (ch == 'n') return;
      System.out.print("Name: ");
      String name = Input.readString();
      Entry entry = search(book, name);
      if (entry == null)
        System.out.println("Name not found.");
      else
        System.out.println("Number: " + entry.getNumber());
    }
  }

  // --------------------------------------------------------------------------
  // searches for 'name' in book; returns corresponding entry 
  // (or null, if entry not found)
  // --------------------------------------------------------------------------
  public static Entry search(Entry[] book, String name)
  {
    final int n = book.length;
    for(int i = 0; i < n; i++)
      if (book[i].getName().equals(name)) return book[i];
    return null;
  }
}
